# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations


class Migration(migrations.Migration):

    dependencies = [
        ('cms', '0003_auto_20140926_2347'),
        ('djangocms_page_image', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='ChildPagePreviewPlugin',
            fields=[
                ('cmsplugin_ptr', models.OneToOneField(parent_link=True, auto_created=True, primary_key=True, serialize=False, to='cms.CMSPlugin')),
            ],
            options={
                'abstract': False,
            },
            bases=('cms.cmsplugin',),
        ),
        migrations.AlterModelOptions(
            name='imageextension',
            options={'verbose_name': 'page image'},
        ),
    ]



from django.contrib import admin
from cms.extensions import PageExtensionAdmin

from .models import ImageExtension

class ImageExtensionAdmin(PageExtensionAdmin):
    pass
admin.site.register(ImageExtension, ImageExtensionAdmin)



from django.db import models
from django.conf import settings

from filer.fields.image import FilerImageField

from django.utils.translation import ugettext_lazy as _

from cms.models import CMSPlugin
from cms.extensions import PageExtension
from cms.extensions.extension_pool import extension_pool

class ImageExtension(PageExtension):
    image = FilerImageField(verbose_name=_('image'), blank=True, null=True)
    preview_image = FilerImageField(
        verbose_name=_('preview image'),
        blank=True,
        null=True,
        help_text=_('leave blank to use page image'),
        related_name='preview_image_extensions'
    )
    teaser = models.TextField(verbose_name=_('teaser'), blank=True)
    show_preview = models.BooleanField(
        verbose_name=_('show preview?'),
        default=True
    )
    extra_classes = models.CharField(verbose_name=_('extra classes'),
        max_length=512, blank=True)

    class Meta:
        verbose_name=_('Page Image and Teaser')

    def get_preview_image(self):
        return self.preview_image or self.image


extension_pool.register(ImageExtension)


class ChildPagePreviewPlugin(CMSPlugin):
    STYLE_CHOICES = getattr(
        settings,
        'DJANGOCMS_PAGE_IMAGE_CPP_STYLE_CHOICES',
        []
    )
    DEFAULT_STYLE = getattr(
        settings,
        'DJANGOCMS_PAGE_IMAGE_CPP_DEFAULT_STYLE',
        ''
    )
    style = models.CharField(
        _('style'),
        choices=STYLE_CHOICES,
        default=DEFAULT_STYLE,
        max_length=50,
        blank=True
    )



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations
import filer.fields.image


class Migration(migrations.Migration):

    dependencies = [
        ('filer', '0001_initial'),
        ('djangocms_page_image', '0004_auto_20150213_1459'),
    ]

    operations = [
        migrations.AddField(
            model_name='imageextension',
            name='preview_image',
            field=filer.fields.image.FilerImageField(related_name='preview_image_extensions', blank=True, to='filer.Image', help_text='leave blank to use page image', null=True, verbose_name='preview image'),
            preserve_default=True,
        ),
    ]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations
from django.conf import settings
from django.utils.translation import ugettext_lazy as _

import filer

STYLE_CHOICES = [
    (x, _(y))
    for x, y
    in getattr(settings, 'DJANGOCMS_PAGE_IMAGE_CPP_STYLE_CHOICES', [])
]
DEFAULT_STYLE = getattr(
    settings,
    'DJANGOCMS_PAGE_IMAGE_CPP_DEFAULT_STYLE',
    ''
)

class Migration(migrations.Migration):

    dependencies = [
        ('djangocms_page_image', '0003_auto_20150125_2116'),
    ]

    operations = [
        migrations.AddField(
            model_name='childpagepreviewplugin',
            name='style',
            field=models.CharField(
                max_length=50,
                verbose_name='style',
                blank=True,
                choices=STYLE_CHOICES,
                default=DEFAULT_STYLE
            ),
            preserve_default=True,
        ),
        migrations.AddField(
            model_name='imageextension',
            name='show_preview',
            field=models.BooleanField(default=True, verbose_name='show preview?'),
            preserve_default=True,
        ),
        migrations.AlterField(
            model_name='imageextension',
            name='image',
            field=filer.fields.image.FilerImageField(verbose_name='image', blank=True, to='filer.Image', null=True),
            preserve_default=True,
        ),
    ]



from cms.extensions.toolbar import ExtensionToolbar
from cms.toolbar_pool import toolbar_pool

from django.utils.translation import ugettext_lazy as _

from .models import ImageExtension

@toolbar_pool.register
class ImageExtensionToolbar(ExtensionToolbar):
    model = ImageExtension

    def populate(self):
        # setup the extension toolbar with permissions and sanity checks
        current_page_menu = self._setup_extension_toolbar()
        # if it's all ok
        if current_page_menu:
            # retrieves the instance of the current extension (if any) and the toolbar item url
            page_extension, url = self.get_page_extension_admin()
            if url:
                # adds a toolbar item
                current_page_menu.add_modal_item(_('Page Image and Teaser'), url=url,
                    disabled=not self.toolbar.edit_mode)



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djangocms_page_image', '0005_imageextension_preview_image'),
    ]

    operations = [
        migrations.AddField(
            model_name='imageextension',
            name='extra_classes',
            field=models.CharField(max_length=512, verbose_name='extra classes', blank=True),
        ),
        migrations.AlterField(
            model_name='childpagepreviewplugin',
            name='cmsplugin_ptr',
            field=models.OneToOneField(parent_link=True, related_name='djangocms_page_image_childpagepreviewplugin', auto_created=True, primary_key=True, serialize=False, to='cms.CMSPlugin'),
        ),
    ]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations
import filer.fields.image


class Migration(migrations.Migration):

    dependencies = [
        ('cms', '0003_auto_20140926_2347'),
        ('filer', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='ImageExtension',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('extended_object', models.OneToOneField(editable=False, to='cms.Page')),
                ('image', filer.fields.image.FilerImageField(verbose_name='image', to='filer.Image')),
                ('public_extension', models.OneToOneField(related_name='draft_extension', null=True, editable=False, to='djangocms_page_image.ImageExtension')),
            ],
            options={
                'abstract': False,
            },
            bases=(models.Model,),
        ),
    ]



from setuptools import setup, find_packages

from djangocms_page_image import __version__

setup(
    name="djangocms-page-image",
    version=__version__,
    url='http://github.com/febsn/djangocms-page-image',
    license='MIT',
    description="django-cms page extension providing image and teaser text",
    long_description=open('README.rst').read(),
    author='Fabian Lehner',
    author_email='fl@makonis.net',
    packages=find_packages(),
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Internet :: WWW/HTTP',
    ],
    install_requires=[
        "Django >= 1.8",
        "django-filer >= 1.2.0",

        "django-cms >= 3.1",
        "django-sekizai >= 0.4.2",
        "easy_thumbnails >= 1.0",
    ],
    include_package_data=True,
    zip_safe=False,
)



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations
import filer.fields.image


class Migration(migrations.Migration):

    dependencies = [
        ('djangocms_page_image', '0002_auto_20150124_0925'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='imageextension',
            options={'verbose_name': 'page image and teaser'},
        ),
        migrations.AddField(
            model_name='imageextension',
            name='teaser',
            field=models.TextField(verbose_name='teaser', blank=True),
            preserve_default=True,
        ),
        migrations.AlterField(
            model_name='imageextension',
            name='image',
            field=filer.fields.image.FilerImageField(verbose_name='image', blank=True, to='filer.Image'),
            preserve_default=True,
        ),
    ]



from django.db.models import Q
from django.template.loader import select_template

from cms.plugin_base import CMSPluginBase
from cms.plugin_pool import plugin_pool

from django.utils.translation import ugettext_lazy as _

from .models import ChildPagePreviewPlugin


class CMSChildPagePreviewPlugin(CMSPluginBase):
    model = ChildPagePreviewPlugin
    name = _("Child Page Preview")

    TEMPLATE_NAME = "djangocms_page_image/plugins/%s.html"
    render_template = TEMPLATE_NAME % 'child_page_preview'

    #Search
    search_fields = []

    def render(self, context, instance, placeholder):
        self.render_template = select_template((
            self.TEMPLATE_NAME % instance.style,
            self.render_template,
        ))
        request = context['request']
        if request.user.has_perm('cms.can_change'):
            subpages = instance.placeholder.page.children.all()
        else:
            subpages = instance.placeholder.page.children.published()
        context['subpages'] = subpages.filter(
            Q(imageextension__show_preview=True) |
            Q(imageextension__isnull=True)
        )
        context['instance'] = instance
        return context

plugin_pool.register_plugin(CMSChildPagePreviewPlugin)
